#
# spec file for package tnef
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tnef
Version:        1.4.18
Release:        bp155.2.10
Summary:        Uncompress MS-TNEF Archives
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://github.com/verdammelt/tnef/
Source:         https://github.com/verdammelt/tnef/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  libtool

%description
This tool uncompresses MS-TNEF archives as used by some mailers.

%prep
%setup -q

%build
if [ ! -x configure ]; then
	autoreconf -fi
fi
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%doc AUTHORS BUGS COPYING ChangeLog NEWS README.md THANKS doc/FAQ contrib/
%{_bindir}/tnef
%{_mandir}/man1/tnef.1%{ext_man}

%changelog
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.18:
  * Improve safety of strdups
  * Correct possible improper bitshift.
* Mon Feb  5 2018 asterios.dramis@gmail.com
- Update to version 1.4.17:
  * Fix embarrassing version number problem.
  From version 1.4.16:
  * Several documentation fixes.
  * Small bug fix for UUID assertion.
* Wed Jul  5 2017 asterios.dramis@gmail.com
- Update to version 1.4.15:
  * Fix underflow problem (boo#1038837 CVE-2017-8911)
    https://github.com/verdammelt/tnef/issues/23
  From version 1.4.14:
  * Use __builtin_mul_overflow when available.
  * Fixing Unicode related bugs introduced in previous release.
    https://github.com/verdammelt/tnef/issues/20
* Mon Feb 27 2017 jengelh@inai.de
- Update to new upstream release 1.4.13
  * Prevent against various cases of null derefences,
    buffer overshooting, and fix some integer overflows.
* Tue Apr  7 2015 p.drouand@gmail.com
- Update to version 1.4.12
  * Fixing bug in distribution tarball.
    https://github.com/verdammelt/tnef/issues/9
  * Fixing autoconf warnings
    https://github.com/verdammelt/tnef/issues/4
    https://github.com/verdammelt/tnef/pull/10
  * Fixing compilation warning on Fedora
    https://github.com/verdammelt/tnef/pull/8
- Changes from version 1.4.11
  * Fixing bug when parsing files with multiple value MAPI attributes
    https://github.com/verdammelt/tnef/issues/3
  * Fixing compilation warnings
    https://github.com/verdammelt/tnef/issues/5
* Sun May  4 2014 asterios.dramis@gmail.com
- Update to 1.4.10:
  * Incorporating documentation patch from bentley.
  * Fixing small problems from new versions of automake/gcc.
* Sun Mar 11 2012 asterios.dramis@gmail.com
- Update to 1.4.9:
  * Fix some memory leaks.
  * Fixes for printing out MIME types.
* Wed Apr 27 2011 asterios.dramis@gmail.com
- Update to 1.4.8:
  * Applied patch for man page from Jari Aalto [patch sf#3104753].
- Minor spec file updates.
- Removed patch from upstream to fix some manpage errors (fixed in new
  version).
* Sat Feb 19 2011 asterios.dramis@gmail.com
- Update to 1.4.7:
  * Reverting to older UTF decoding method.
  * Updating main copyright date notice.
  From 1.4.6:
  * Including patch from Randy Diffenderfer for a variety of fixes & tweaks.
  * Replacing my buggy/wrong UTF converter code with public domain UTF
    converter code.
  From 1.4.5:
  * Fixing bug when reading from stdin [Bug #2126695]
  From 1.4.4:
  * Small updates after long absense
  * Adding --ignore-checksum feature.
  From 1.4.3:
  * Fixing 'unicode string filename' bug [Bug #1546546].
  From 1.4.2:
  * Fixing 'garbage at end of file' bug [Bug# 1513940]. Now tries to handle
    gracefully
  * Fixing Solaris 10 empty libreplace.a bug [Bug# 1517789]. Now libreplace.a
    never empty.
  From 1.4.1:
  * Applied patch from Tony Aiuto <tony@ics.com> to add the ability to list the
    file mime types.
  From 1.4:
  * Code reorganization
  * New MAPI property names
  * Fixing parsing of multi-value MAPI properties [Bug# 1434145]
  From 1.3.4:
  * Fixing RTF message body saving [Bug#  1318728].  Fix courtesy of Eduardo
    Subelman.
  From 1.3.3:
  * Fixing memory leak bug [Bug# 1168062].  GUIDs not being freed corrrectly.
  * Fixing tnef.spec.in bug [Bug# 1200197]. Adding fix to RedHat package
    building problem from John Simpson <jms1@users.sourceforge.net>
  * Now saving message body data [RFE# 1033855]. Now optionally saves message
    body data, generalizing the previous --save-rtf feature.
  * Implementing Unicode handling [Patch# 666561].  Implementing code to
    translate Unicode strings to uft8 as best as can be.  Snitched code from
    ytnef <URL: www.sourceforge.net/projects/ytnef>  Thanks
    yerase@users.sourceforge.net!
  From 1.3.2:
  * Fixing test buf [Bug# 1121539].  Tests failed due to 32 vs. 64 bit diff.
  * Fixing compile bug [Bug# 1109683].  Basename declared incorrectly
  * Fixing endian bug [Bug# 1117373].  GUIDs were not being parsed, only copied
    out of stream, thus endianess was wrong left up to chance
  From 1.3.1:
  * Fixing dumb compiling bugs [BUG: #1108485].  GCC lets me write incorrect code!
  * Small modifications to tnef.spec.in as suggested by jmsl@users.sf.net [BUG:
    [#1102128]]
  * Corrected type problems to improve portability to 64 bit systems and Mac.
  From 1.3:
  * Adding feature to allow for saving of RTF data.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Added Url: entry.
  * Updates in %%build and %%install sections.
  * Removed %%changelog entries from spec file.
- Added a patch from upstream to fix some manpage errors.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug 23 2004 mmj@suse.de
- Update to 1.2.3.1 which obsoletes our patches
* Thu May  6 2004 hmacht@suse.de
- added norootforbuild in specfile
* Thu Apr 22 2004 pth@suse.de
- Fix configure.in and acinclude.m4.
- Define _GNU_SOURCE unconditionally to get basename declaration.
- Include headers where necessary.
* Wed Jun 18 2003 coolo@suse.de
- use BuildRoot
* Wed Dec  5 2001 uli@suse.de
- update -> 1.1.1 (cosmetic, just to keep people from complaining)
* Thu Aug 16 2001 uli@suse.de
- update -> 1.1
* Mon Apr  9 2001 uli@suse.de
- update -> 1.0.1
* Thu Apr  5 2001 uli@suse.de
- update -> 1.0
- fixed Group tag
* Tue Sep 19 2000 uli@suse.de
- removed so-called "sanity check" which makes tnef virtually unusable
* Mon Jul 17 2000 stark@suse.de
- added <unistd.h>
- fixed spec-file for compiling patched sources
* Mon Jul  3 2000 uli@suse.de
- added secfix
* Tue Jun 27 2000 dipa@suse.de
- add a customer dif-file
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 10 1999 uli@suse.de
- new package
